@@ -6,8 +6,12 @@ import time
 import urllib.parse
 import zipfile
 import threading
+import socket
 
 import requests
+import requests.adapters
+from urllib3.connection import HTTPConnection
+
 from oauthlib.oauth2 import BackendApplicationClient, TokenExpiredError
 from requests_oauthlib import OAuth2Session
 
@@ -27,6 +31,26 @@ def quote_id_for_url(item_id):
     return urllib.parse.quote(item_id, safe="")
 
 
+# IS-10192: from https://carsonip.me/posts/azure-tcp-idle-timeout-tcp-keepalive-python/
+class HTTPAdapterWithSocketOptions(requests.adapters.HTTPAdapter):
+    def __init__(self, *args, **kwargs):
+        self.socket_options = kwargs.pop("socket_options", None)
+        super(HTTPAdapterWithSocketOptions, self).__init__(*args, **kwargs)
+
+    def init_poolmanager(self, *args, **kwargs):
+        if self.socket_options is not None:
+            kwargs["socket_options"] = self.socket_options
+        super(HTTPAdapterWithSocketOptions, self).init_poolmanager(*args, **kwargs)
+
+
+class HTTPAdapterWithTCPKeepalive(HTTPAdapterWithSocketOptions):
+    def __init__(self, *args, **kwargs):
+        self.socket_options = HTTPConnection.default_socket_options + [
+                                (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1),
+                            ]
+        super(HTTPAdapterWithTCPKeepalive, self).__init__(*args, **kwargs)
+
+
 class Connection:
     """This class represents a connection to a Sesam installation. This is the starting point of all interactions
     with the Sesam installation.
@@ -75,6 +99,7 @@ class Connection:
         self._oauth2_session = None
         self._oauth2_token = None
         self._session = None
+        self._adapter = HTTPAdapterWithTCPKeepalive()
 
     def set_jwt_auth_token(self, jwt_auth_token):
         """Replaces the current jwt_auth_token (if any) with the new jwt."""
@@ -89,7 +114,6 @@ class Connection:
     @property
     def session(self):
         if self._oauth2_config is not None:
-
             oauth2_config = self._oauth2_config
 
             if self._oauth2_client is None:
@@ -100,6 +124,10 @@ class Connection:
                 if self._headers:
                     self._oauth2_session.headers = self._headers
 
+                # IS-10192: turn on TCP keep-alive to avoid indefinitely hanging connections
+                self._oauth2_session.mount("http://", self._adapter)
+                self._oauth2_session.mount("https://", self._adapter)
+
             # If no token has been created yet or if the previous token has expired (or is close to it),
             # fetch a new access token before returning the session to the callee.
             if self._oauth2_token is None or self._oauth2_token["expires_at"] <= (time.time() + 60):
@@ -129,6 +157,9 @@ class Connection:
                     session.cert = self._client_certificate
                 session.headers = self._headers
 
+                # IS-10192: turn on TCP keep-alive to avoid indefinitely hanging connections
+                self._session.mount("http://", self._adapter)
+                self._session.mount("https://", self._adapter)
             return self._session
 
     def __enter__(self):
