@@ -28,12 +28,12 @@ class EntityBase:
                     type(raw_jsondata), raw_jsondata))
         self._raw_jsondata = raw_jsondata
 
-    def update_raw_jsondata_from_url(self, url):
+    def update_raw_jsondata_from_url(self, url, **kwargs):
         """Utility-method for updating this object with new information from the specified url. This is typically
         used by a subclass when it knows that an operation has resulted in a change in the state, or when it knows
         that it needs up-to-date information (example: ScheduledTash.get_running_task())
         """
-        response = self._connection.do_get_request(url, allowable_response_status_codes=[200])
+        response = self._connection.do_get_request(url, allowable_response_status_codes=[200], **kwargs)
         self.update_raw_jsondata(response.content.decode("utf-8"))
 
     def update_raw_jsondata(self, new_raw_jsondata):
